bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.get_shape
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.get_shape